==> eam-wshub-proxyclient-11.4-14-sources.jar: net/datastream/schemas/mp_entities/workorder_001/ESignatureDetail.java <==

package net.datastream.schemas.mp_entities.workorder_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.USERID_Type;
import org.openapplications.oagis_segments.DATETIME;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ESIGNER" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ESIGNATUREDATE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SIGNATURETYPE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ERECORDCODE" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "esigner",
    "esignaturedate",
    "signaturetype",
    "erecordcode"
})
@XmlRootElement(name = "ESignatureDetail")
public class ESignatureDetail {

    @XmlElement(name = "ESIGNER", namespace = "http://schemas.datastream.net/MP_fields")
    protected USERID_Type esigner;
    @XmlElement(name = "ESIGNATUREDATE", namespace = "http://schemas.datastream.net/MP_fields")
    protected DATETIME esignaturedate;
    @XmlElement(name = "SIGNATURETYPE", namespace = "http://schemas.datastream.net/MP_fields")
    protected String signaturetype;
    @XmlElement(name = "ERECORDCODE", namespace = "http://schemas.datastream.net/MP_fields")
    protected String erecordcode;

    /**
     * Obtient la valeur de la propriété esigner.
     * 
     * @return
     *     possible object is
     *     {@link USERID_Type }
     *     
     */
    public USERID_Type getESIGNER() {
        return esigner;
    }

    /**
     * Définit la valeur de la propriété esigner.
     * 
     * @param value
     *     allowed object is
     *     {@link USERID_Type }
     *     
     */
    public void setESIGNER(USERID_Type value) {
        this.esigner = value;
    }

    /**
     * Obtient la valeur de la propriété esignaturedate.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getESIGNATUREDATE() {
        return esignaturedate;
    }

    /**
     * Définit la valeur de la propriété esignaturedate.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setESIGNATUREDATE(DATETIME value) {
        this.esignaturedate = value;
    }

    /**
     * Obtient la valeur de la propriété signaturetype.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getSIGNATURETYPE() {
        return signaturetype;
    }

    /**
     * Définit la valeur de la propriété signaturetype.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setSIGNATURETYPE(String value) {
        this.signaturetype = value;
    }

    /**
     * Obtient la valeur de la propriété erecordcode.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getERECORDCODE() {
        return erecordcode;
    }

    /**
     * Définit la valeur de la propriété erecordcode.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setERECORDCODE(String value) {
        this.erecordcode = value;
    }

}

==> eam-wshub-proxyclient-11.7-2-sources.jar: net/datastream/schemas/mp_entities/workorder_001/ESignatureDetail.java <==

package net.datastream.schemas.mp_entities.workorder_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.USERID_Type;
import org.openapplications.oagis_segments.DATETIME;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ESIGNER" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ESIGNATUREDATE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SIGNATURETYPE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ERECORDCODE" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "esigner",
    "esignaturedate",
    "signaturetype",
    "erecordcode"
})
@XmlRootElement(name = "ESignatureDetail")
public class ESignatureDetail {

    @XmlElement(name = "ESIGNER", namespace = "http://schemas.datastream.net/MP_fields")
    protected USERID_Type esigner;
    @XmlElement(name = "ESIGNATUREDATE", namespace = "http://schemas.datastream.net/MP_fields")
    protected DATETIME esignaturedate;
    @XmlElement(name = "SIGNATURETYPE", namespace = "http://schemas.datastream.net/MP_fields")
    protected String signaturetype;
    @XmlElement(name = "ERECORDCODE", namespace = "http://schemas.datastream.net/MP_fields")
    protected String erecordcode;

    /**
     * Gets the value of the esigner property.
     * 
     * @return
     *     possible object is
     *     {@link USERID_Type }
     *     
     */
    public USERID_Type getESIGNER() {
        return esigner;
    }

    /**
     * Sets the value of the esigner property.
     * 
     * @param value
     *     allowed object is
     *     {@link USERID_Type }
     *     
     */
    public void setESIGNER(USERID_Type value) {
        this.esigner = value;
    }

    /**
     * Gets the value of the esignaturedate property.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getESIGNATUREDATE() {
        return esignaturedate;
    }

    /**
     * Sets the value of the esignaturedate property.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setESIGNATUREDATE(DATETIME value) {
        this.esignaturedate = value;
    }

    /**
     * Gets the value of the signaturetype property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getSIGNATURETYPE() {
        return signaturetype;
    }

    /**
     * Sets the value of the signaturetype property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setSIGNATURETYPE(String value) {
        this.signaturetype = value;
    }

    /**
     * Gets the value of the erecordcode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getERECORDCODE() {
        return erecordcode;
    }

    /**
     * Sets the value of the erecordcode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setERECORDCODE(String value) {
        this.erecordcode = value;
    }

}
